@@ -1,5 +1,8 @@
 package Net::HTTP::Methods::Patch::LogRequest;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.09'; # VERSION
+
 use 5.010001;
 use strict;
 no warnings;
@@ -7,12 +10,11 @@ no warnings;
 use Module::Patch 0.12 qw();
 use base qw(Module::Patch);
 
-our $VERSION = '0.08'; # VERSION
-
 our %config;
 
-my $p_log_request = sub {
-    require Log::Any;
+my $p_format_request = sub {
+    require Log::Any::IfLOG;
+    my $log = Log::Any::IfLOG->get_logger;
 
     my $ctx = shift;
     my $orig = $ctx->{orig};
@@ -20,7 +22,6 @@ my $p_log_request = sub {
 
     my $proto = ref($_[0]) =~ /^LWP::Protocol::(\w+)::/ ? $1 : "?";
 
-    my $log = Log::Any->get_logger;
     if ($log->is_trace) {
 
         # there is no equivalent of caller_depth in Log::Any, so we do this only
@@ -28,9 +29,8 @@ my $p_log_request = sub {
         local $Log::Log4perl::caller_depth = $Log::Log4perl::caller_depth + 1
             if $Log::{"Log4perl::"};
 
-        $log->tracef("HTTP request (proto=%s, len=%d):\n%s",
+        $log->tracef("HTTP request (proto=%s, len(headers)=%d):\n%s",
                      $proto, length($res), $res);
-
     }
     $res;
 };
@@ -43,26 +43,28 @@ sub patch_data {
                 action      => 'wrap',
                 mod_version => qr/^6\.0.*/,
                 sub_name    => 'format_request',
-                code        => $p_log_request,
+                code        => $p_format_request,
             },
         ],
-    };
+   };
 }
 
 1;
 # ABSTRACT: Log raw HTTP requests
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::HTTP::Methods::Patch::LogRequest - Log raw HTTP requests
 
 =head1 VERSION
 
-version 0.08
+This document describes version 0.09 of Net::HTTP::Methods::Patch::LogRequest (from Perl distribution Net-HTTP-Methods-Patch-LogRequest), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -109,16 +111,35 @@ see that it is already doing that (albeit commented):
 By patching, you do not need to replace all the client code which uses LWP (or
 WWW::Mechanize, etc).
 
+=head2 How to log request content?
+
+See L<LWP::UserAgent::Patch::LogRequestContent>.
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Net-HTTP-Methods-Patch-LogRequest>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Net-HTTP-Methods-Patch-LogRequest>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Net-HTTP-Methods-Patch-LogRequest>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
